@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-    Author: Volker Krause <volker.krause@kdab.com>
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+    SPDX-FileContributor: Volker Krause <volker.krause@kdab.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KSIEVE_KMANAGESIEVE_SESSION_H
@@ -59,7 +46,7 @@ public:
     void killJob(SieveJob *job, KJob::KillVerbosity verbosity);
     void sendData(const QByteArray &data);
 
-    QStringList sieveExtensions() const;
+    Q_REQUIRED_RESULT QStringList sieveExtensions() const;
 
     /**
      * @return true if we are not connected nor currently connecting, i.e. it's ok to call connectToHost()
@@ -67,15 +54,15 @@ public:
     bool disconnected() const;
 
 private:
-    bool requestCapabilitiesAfterStartTls() const;
+    Q_REQUIRED_RESULT bool requestCapabilitiesAfterStartTls() const;
 
-    QStringList requestedSaslMethod() const;
-    bool allowUnencrypted() const;
+    Q_REQUIRED_RESULT QStringList requestedSaslMethod() const;
+    Q_REQUIRED_RESULT bool allowUnencrypted() const;
 
 private Q_SLOTS:
     void setErrorMessage(int error, const QString &msg);
     void processResponse(const KManageSieve::Response &response, const QByteArray &data);
-    KManageSieve::AuthDetails requestAuthDetails(const QUrl &url);
+    Q_REQUIRED_RESULT KManageSieve::AuthDetails requestAuthDetails(const QUrl &url);
     void authenticationDone();
     void sslError(const KSslErrorUiData &data);
     void sslDone();
@@ -98,10 +85,10 @@ private:
         StartTls,
         Authenticating
     };
-    State m_state;
+    State m_state = None;
     bool m_supportsStartTls = false;
     bool m_connected = false;
-    bool m_disconnected = false;
+    bool m_disconnected = true;
 
     friend class SessionThread;
 };
