@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionextracttext.h"
 #include "editor/sieveeditorutil.h"
@@ -37,14 +24,14 @@ SieveActionExtractText::SieveActionExtractText(SieveEditorGraphicalModeWidget *s
 QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto *grid = new QGridLayout;
+    grid->setContentsMargins({});
     w->setLayout(grid);
 
     QLabel *lab = new QLabel(i18n("Number of characters:"));
     grid->addWidget(lab, 0, 0);
 
-    QSpinBox *nbCharacters = new QSpinBox;
+    auto *nbCharacters = new QSpinBox;
     nbCharacters->setMinimum(1);
     nbCharacters->setMaximum(99999);
     nbCharacters->setObjectName(QStringLiteral("numberOfCharacters"));
@@ -54,7 +41,7 @@ QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Stored in variable name:"));
     grid->addWidget(lab, 1, 0);
 
-    QLineEdit *variableName = new QLineEdit;
+    auto *variableName = new QLineEdit;
     connect(variableName, &QLineEdit::textChanged, this, &SieveActionExtractText::valueChanged);
     variableName->setObjectName(QStringLiteral("variablename"));
     grid->addWidget(variableName, 1, 1);
@@ -62,7 +49,7 @@ QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionExtractText::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionExtractText::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
@@ -71,10 +58,10 @@ bool SieveActionExtractText::setParamWidgetValue(QXmlStreamReader &element, QWid
             element.skipCurrentElement();
             //TODO ?
         } else if (tagName == QLatin1String("num")) {
-            QSpinBox *numberOfCharacters = w->findChild<QSpinBox *>(QStringLiteral("numberOfCharacters"));
+            auto *numberOfCharacters = w->findChild<QSpinBox *>(QStringLiteral("numberOfCharacters"));
             numberOfCharacters->setValue(element.readElementText().toInt());
         } else if (tagName == QLatin1String("str")) {
-            QLineEdit *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
+            auto *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
             variableName->setText(element.readElementText());
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
@@ -87,8 +74,6 @@ bool SieveActionExtractText::setParamWidgetValue(QXmlStreamReader &element, QWid
             qCDebug(LIBKSIEVE_LOG) << " SieveActionExtractText::setParamWidgetValue unknown tagName " << tagName;
         }
     }
-
-    return true;
 }
 
 QString SieveActionExtractText::code(QWidget *w) const
