@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionmetadataexists.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
@@ -38,8 +25,8 @@ SieveConditionMetaDataExists::SieveConditionMetaDataExists(SieveEditorGraphicalM
 QWidget *SieveConditionMetaDataExists::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto *grid = new QGridLayout;
+    grid->setContentsMargins({});
     w->setLayout(grid);
 
     QLabel *lab = new QLabel(i18n("Mailbox:"));
@@ -54,7 +41,7 @@ QWidget *SieveConditionMetaDataExists::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Annotation:"));
     grid->addWidget(lab, 1, 0);
 
-    QLineEdit *value = new QLineEdit;
+    auto *value = new QLineEdit;
     connect(value, &QLineEdit::textChanged, this, &SieveConditionMetaDataExists::valueChanged);
     value->setObjectName(QStringLiteral("value"));
     grid->addWidget(value, 1, 1);
@@ -92,7 +79,7 @@ QString SieveConditionMetaDataExists::help() const
     return i18n("The \"metadataexists\" test is true if all of the annotations listed in the \"annotation-names\" argument exist for the specified mailbox.");
 }
 
-bool SieveConditionMetaDataExists::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
+void SieveConditionMetaDataExists::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
 {
     int index = 0;
     QString commentStr;
@@ -101,10 +88,10 @@ bool SieveConditionMetaDataExists::setParamWidgetValue(QXmlStreamReader &element
         if (tagName == QLatin1String("str")) {
             const QString tagValue = element.readElementText();
             if (index == 0) {
-                KSieveUi::AbstractMoveImapFolderWidget *mailbox = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("mailbox"));
+                auto *mailbox = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("mailbox"));
                 mailbox->setText(tagValue);
             } else if (index == 1) {
-                QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("value"));
+                auto *value = w->findChild<QLineEdit *>(QStringLiteral("value"));
                 value->setText(AutoCreateScriptUtil::quoteStr(tagValue));
             } else {
                 tooManyArguments(tagName, index, 2, error);
@@ -124,8 +111,6 @@ bool SieveConditionMetaDataExists::setParamWidgetValue(QXmlStreamReader &element
     if (!commentStr.isEmpty()) {
         setComment(commentStr);
     }
-
-    return true;
 }
 
 QUrl SieveConditionMetaDataExists::href() const
