@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionservermetadata.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
@@ -39,23 +26,23 @@ SieveConditionServerMetaData::SieveConditionServerMetaData(SieveEditorGraphicalM
 QWidget *SieveConditionServerMetaData::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    SelectMatchTypeComboBox *selectType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto *selectType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     selectType->setObjectName(QStringLiteral("selecttype"));
     connect(selectType, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionServerMetaData::valueChanged);
     lay->addWidget(selectType);
 
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto *grid = new QGridLayout;
+    grid->setContentsMargins({});
     lay->addLayout(grid);
 
     QLabel *lab = new QLabel(i18n("Mailbox:"));
     grid->addWidget(lab, 0, 0);
 
-    QLineEdit *mailbox = new QLineEdit;
+    auto *mailbox = new QLineEdit;
     mailbox->setObjectName(QStringLiteral("mailbox"));
     connect(mailbox, &QLineEdit::textChanged, this, &SieveConditionServerMetaData::valueChanged);
     grid->addWidget(mailbox, 0, 1);
@@ -63,7 +50,7 @@ QWidget *SieveConditionServerMetaData::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Annotations:"));
     grid->addWidget(lab, 1, 0);
 
-    QLineEdit *annotation = new QLineEdit;
+    auto *annotation = new QLineEdit;
     connect(annotation, &QLineEdit::textChanged, this, &SieveConditionServerMetaData::valueChanged);
     annotation->setObjectName(QStringLiteral("annotation"));
     grid->addWidget(annotation, 1, 1);
@@ -127,7 +114,7 @@ QString SieveConditionServerMetaData::help() const
         "This test retrieves the value of the server annotation \"annotation-name\".  The retrieved value is compared to the \"key-list\". The test returns true if the annotation exists and its value matches any of the keys.");
 }
 
-bool SieveConditionServerMetaData::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
+void SieveConditionServerMetaData::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
 {
     int index = 0;
     QString commentStr;
@@ -138,19 +125,19 @@ bool SieveConditionServerMetaData::setParamWidgetValue(QXmlStreamReader &element
             switch (index) {
             case 0:
             {
-                QLineEdit *mailbox = w->findChild<QLineEdit *>(QStringLiteral("mailbox"));
+                auto *mailbox = w->findChild<QLineEdit *>(QStringLiteral("mailbox"));
                 mailbox->setText(tagValue);
                 break;
             }
             case 1:
             {
-                QLineEdit *annotation = w->findChild<QLineEdit *>(QStringLiteral("annotation"));
+                auto *annotation = w->findChild<QLineEdit *>(QStringLiteral("annotation"));
                 annotation->setText(tagValue);
                 break;
             }
             case 2:
             {
-                AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+                auto *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
                 value->setCode(tagValue);
                 break;
             }
@@ -161,7 +148,7 @@ bool SieveConditionServerMetaData::setParamWidgetValue(QXmlStreamReader &element
             }
             ++index;
         } else if (tagName == QLatin1String("tag")) {
-            SelectMatchTypeComboBox *selectType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("selecttype"));
+            auto *selectType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("selecttype"));
             selectType->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), notCondition), name(), error);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
@@ -176,8 +163,6 @@ bool SieveConditionServerMetaData::setParamWidgetValue(QXmlStreamReader &element
     if (!commentStr.isEmpty()) {
         setComment(commentStr);
     }
-
-    return true;
 }
 
 QUrl SieveConditionServerMetaData::href() const
