@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveeditortabwidget.h"
 #include "webengine/sieveeditorhelphtmlwidget.h"
@@ -125,13 +112,13 @@ void SieveEditorTabWidget::slotTabCloseRequested(int index)
 
 bool SieveEditorTabWidget::currentPageIsHtmlPage() const
 {
-    SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
     return page ? true : false;
 }
 
 QUrl SieveEditorTabWidget::currentHelpUrl() const
 {
-    SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
     if (page) {
         return page->currentUrl();
     }
@@ -140,7 +127,7 @@ QUrl SieveEditorTabWidget::currentHelpUrl() const
 
 QString SieveEditorTabWidget::currentHelpTitle() const
 {
-    SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
     if (page) {
         return page->title();
     }
@@ -150,13 +137,13 @@ QString SieveEditorTabWidget::currentHelpTitle() const
 void SieveEditorTabWidget::slotAddHelpPage(const QUrl &url)
 {
     for (int i = 0; i < count(); ++i) {
-        SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(widget(i));
+        auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(widget(i));
         if (page && page->currentUrl() == url) {
             setCurrentIndex(i);
             return;
         }
     }
-    SieveEditorHelpHtmlWidget *htmlPage = new SieveEditorHelpHtmlWidget;
+    auto *htmlPage = new SieveEditorHelpHtmlWidget;
     connect(htmlPage, &SieveEditorHelpHtmlWidget::titleChanged, this, &SieveEditorTabWidget::slotTitleChanged);
     connect(htmlPage, &SieveEditorHelpHtmlWidget::progressIndicatorPixmapChanged, this, &SieveEditorTabWidget::slotProgressIndicatorPixmapChanged);
     connect(htmlPage, &SieveEditorHelpHtmlWidget::loadFinished, this, &SieveEditorTabWidget::slotLoadFinished);
