@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2017 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KSIEVE_KSIEVEUI_XMLPRINTINGSCRIPTBUILDER_H
@@ -54,9 +41,9 @@ public:
     void error(const KSieve::Error &error) override;
     void finished() override;
 
-    QString result() const;
-    QString error() const;
-    bool hasError() const;
+    Q_REQUIRED_RESULT QString result() const;
+    Q_REQUIRED_RESULT QString error() const;
+    Q_REQUIRED_RESULT bool hasError() const;
 
     void clear();
 
