@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef VACATIONCHECKJOB_H
@@ -37,10 +26,10 @@ public:
     void setKep14Support(bool kep14Support);
     void start();
     void kill();
-    bool noScriptFound() const;
-    QString script() const;
-    QStringList sieveCapabilities() const;
-    QString serverName() const;
+    Q_REQUIRED_RESULT bool noScriptFound() const;
+    Q_REQUIRED_RESULT QString script() const;
+    Q_REQUIRED_RESULT QStringList sieveCapabilities() const;
+    Q_REQUIRED_RESULT QString serverName() const;
 
 Q_SIGNALS:
     void vacationScriptActive(VacationCheckJob *job, const QString &sscriptName, bool active);
@@ -53,16 +42,16 @@ private Q_SLOTS:
     void emitError(const QString &errorMessage);
     void searchVacationScript();
     void getNextScript();
-    bool isLastScript() const;
 
 private:
+    Q_REQUIRED_RESULT bool isLastScript() const;
     Q_DISABLE_COPY(VacationCheckJob)
     QStringList mAvailableScripts;
     QStringList mActiveScripts;
     QStringList mSieveCapabilities;
     QString mScript;
-    QString mServerName;
-    QUrl mUrl;
+    const QString mServerName;
+    const QUrl mUrl;
     KManageSieve::SieveJob *mSieveJob = nullptr;
     ParseUserScriptJob *mParseJob = nullptr;
     int mScriptPos = -1;
